Installation - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Installation

To use Betty, you must first install Betty’s requirements and then install Betty itself.

## Installing requirements

### Linux, macOS, or Windows

You must use one of these desktop operating systems to be able to run Betty.

### Python

Betty requires Python 3.11 or higher.

### Node.js

Some optional parts of Betty use third-party JavaScript packages to help build your site.

If Betty shows you an error telling you you need npm or Node.js, then in order to use that functionality, you must:

1. install Node.js 20 or higher following the instructions shown there

2. ensure `npm` (the Node.js package manager) is in your `PATH`, e.g. that `npm` can be run in a terminal from anywhere. When running `npm --help` in a terminal shows you npm’s usage instructions, then you’re all set.

### Poppler

If your ancestry includes PDF files, then Betty requires Poppler. There several ways to install this, including but not limited to:

#### Linux: Debian, Ubuntu, etc.

Run `apt install poppler-utils`

#### Linux: CentOS, Fedora, RHEL, etc.

Run `yum install poppler-utils`

#### macOS

Install with Homebrew: `brew install poppler`

#### Windows

Install with Scoop: `scoop install main/poppler`

## Installing Betty itself

Use one of the following methods:

### pip

Run `pip install betty` to install the latest stable release.

### pipx

Run `pipx install betty` to install the latest stable release.

### poetry

Run `poetry add betty` to install the latest stable release.

### From source

This also requires Bash.

Run the following to install the latest unstable version:

1. `git clone https://github.com/bartfeenstra/betty.git`

2. `cd betty`

3. `./bin/build`